@@ -28,15 +28,14 @@ from data_check.config import DataCheckConfig
     type=str,
     default=DataCheckConfig.default_print_format,
     help=(
-        "format for printing failed results (pandas, csv); "
+        "format for printing failed results (pandas, csv, json); "
         f"default: {DataCheckConfig.default_print_format}"
     ),
 )
 @click.option(
-    "--print-csv",
-    "print_csv",
+    "--print-json",
     is_flag=True,
-    help="shortcut for --print --print-format csv",
+    help="shortcut for --print --print-format json",
 )
 @click.option(
     "--gen",
@@ -77,8 +76,18 @@ from data_check.config import DataCheckConfig
     "--load-tables", is_flag=True, help="load tables from a list of csv files"
 )
 @click.option(
-    "--run-sql", is_flag=True, help="run any SQL script in a list of SQL files"
+    "--sql-file",
+    "--sql-files",
+    "sql_files",
+    is_flag=True,
+    help="run any SQL script in a list of SQL files",
 )
+@click.option(
+    "--sql",
+    type=str,
+    help="run any SQL statement; print result as CSV if it is a query",
+)
+@click.option("--output", "-o", type=click.Path(), help="output path for --sql")
 @click.option("--ping", is_flag=True, help="tries to connect to the database")
 @click.option("--verbose", is_flag=True, help="print verbose output")
 @click.option("--traceback", is_flag=True, help="print traceback output for debugging")
@@ -89,7 +98,7 @@ def main(
     workers: int = DataCheckConfig.parallel_workers,
     print_failed: bool = False,
     print_format: str = DataCheckConfig.default_print_format,
-    print_csv: bool = False,
+    print_json: bool = False,
     generate_expectations: bool = False,
     force: bool = False,
     config: Union[str, Path] = DataCheckConfig.config_path,
@@ -97,7 +106,9 @@ def main(
     table: Optional[str] = None,
     load_mode: str = "truncate",
     load_tables: bool = False,
-    run_sql: bool = False,
+    sql_files: bool = False,
+    sql: str = "",
+    output: Union[str, Path] = "",
     ping: bool = False,
     verbose: bool = False,
     traceback: bool = False,
@@ -105,15 +116,17 @@ def main(
 ):
     """ FILES: list of checks files or folders"""
 
-    if print_csv:
+    if print_json:
         print_failed = True
-        print_format = "csv"
+        print_format = "json"
 
     init()  # init colorama
     config = Path(config)
     dc_config = (
         DataCheckConfig(config_path=config).load_config().set_connection(connection)
     )
+    dc_config.generate_mode = generate_expectations
+    dc_config.force = force
 
     if not dc_config.connection:
         click.echo(f"unknown connection: {connection}")
@@ -147,18 +160,22 @@ def main(
 
     dc.load_template()
 
-    if run_sql:
+    if sql_files:
         path_list = [Path(f) for f in files]
         dc.run_sql_files(path_list)
         sys.exit(0)
 
+    if sql:
+        if dc.run_sql_query(sql, output=output):
+            sys.exit(0)
+        else:
+            sys.exit(1)
+
     if not files:
         files = [dc_config.checks_path]  # use default checks path if nothing is given
     path_list = [Path(f) for f in files]
 
-    if generate_expectations:
-        dc.generate_expectations(path_list, force)
-    elif ping:
+    if ping:
         test = dc.sql.test_connection()
         if test:
             click.echo("connecting succeeded")
