@@ -2,6 +2,7 @@ from typing import List, Dict, Any, Union, Optional
 from pathlib import Path
 from jinja2 import Template
 import pandas as pd
+from pandas.core.frame import DataFrame
 import yaml
 
 
@@ -53,10 +54,13 @@ def get_expect_file(sql_file: Path) -> Path:
 
 
 def read_csv(
-    csv_file: Path, parse_dates: Union[bool, List[str]] = False
+    csv_file: Path,
+    parse_dates: Union[bool, List[str]] = False,
+    string_columns: Dict[str, str] = {},
 ) -> pd.DataFrame:
     if not parse_dates:
         parse_dates = False
+    dtypes = {s: "object" for s in string_columns}
     return pd.read_csv(
         csv_file,
         na_values=[""],  # use empty string as nan
@@ -67,9 +71,21 @@ def read_csv(
         engine="c",
         parse_dates=parse_dates,
         infer_datetime_format=True,
+        dtype=dtypes,
     )
 
 
+def print_csv(df: DataFrame):
+    print(df.to_csv(index=False))
+
+
+def write_csv(
+    df: DataFrame, output: Union[str, Path] = "", base_path: Path = Path(".")
+):
+    if output:
+        df.to_csv(base_path / output, index=False)
+
+
 def read_yaml(
     yaml_file: Path,
     encoding: str = "UTF-8",
@@ -79,3 +95,14 @@ def read_yaml(
     if template_data:
         data = parse_template(data, template_data)
     return yaml.safe_load(data)
+
+
+def rel_path(path: Path) -> Path:
+    """
+    Returns the path relative to where data_check is started from
+    if it's relative to this path.
+    """
+    try:
+        return path.absolute().relative_to(Path(".").absolute())
+    except ValueError:
+        return path
