@@ -9,10 +9,12 @@ from enum import Enum
 import warnings
 from pathlib import Path
 import datetime
+from dateutil.parser import isoparse
+from collections import namedtuple
 
 
 from .exceptions import DataCheckException
-from .io import expand_files, read_csv
+from .io import expand_files, read_csv, print_csv, write_csv
 from .runner import DataCheckRunner
 
 
@@ -33,6 +35,19 @@ class LoadMode(Enum):
             raise DataCheckException(f"unknown load mode: {mode_name}")
 
 
+# some data types that need special handling
+ColumnInfo = namedtuple(
+    "ColumnInfo",
+    [
+        "dtypes",
+        "date_columns",
+        "date_column_names",
+        "string_columns",
+        "string_column_names",
+    ],
+)
+
+
 class DataCheckSql:
     def __init__(
         self, connection: str, runner: DataCheckRunner = DataCheckRunner(workers=1)
@@ -81,6 +96,27 @@ class DataCheckSql:
     def dialect(self) -> str:
         return self.get_connection().dialect.name
 
+    @staticmethod
+    def date_parser(ds):
+        if isinstance(ds, str):
+            return isoparse(ds)
+        return ds
+
+    def parse_date_hint(self, query: str) -> List[str]:
+        lines = [l.strip() for l in query.splitlines()]
+        comment_lines = [
+            l.replace("--", "", 1).strip() for l in lines if l.startswith("--")
+        ]
+        date_hints = [
+            l.replace("date:", "", 1) for l in comment_lines if l.startswith("date:")
+        ]
+
+        hints = []
+        for dh in date_hints:
+            _hints = dh.split(",")
+            hints.extend(h.strip() for h in _hints)
+        return hints
+
     def run_query(self, query: str) -> pd.DataFrame:
         """
         Run a query on the database and return a Pandas DataFrame with the result.
@@ -101,11 +137,11 @@ class DataCheckSql:
         except:  # noqa E722
             return False
 
-    def table_exists(self, table_name: str, schema: str):
+    def table_exists(self, table_name: str, schema: Optional[str]):
         inspector = inspect(self.get_connection())
         return inspector.has_table(table_name=table_name, schema=schema)
 
-    def drop_table_if_exists(self, table_name: str, schema: str):
+    def drop_table_if_exists(self, table_name: str, schema: Optional[str]):
         if self.table_exists(table_name, schema):
             if schema:
                 drop_stmt = f"DROP TABLE {schema}.{table_name}"
@@ -115,13 +151,21 @@ class DataCheckSql:
                 text(drop_stmt).execution_options(autocommit=True)
             )
 
+    def _truncate_statement(self, table_name: str) -> str:
+        if self.dialect == "sqlite":
+            return f"DELETE FROM {table_name}"
+        else:
+            return f"TRUNCATE TABLE {table_name}"
+
     def _prepare_table_for_load(self, table_name: str, load_mode: LoadMode):
         if load_mode == LoadMode.TRUNCATE:
             schema, name = self._parse_table_name(table_name)
             inspector = inspect(self.get_connection())
             if inspector.has_table(table_name=name, schema=schema):
                 self.get_connection().execute(
-                    text(f"DELETE FROM {table_name}").execution_options(autocommit=True)
+                    text(self._truncate_statement(table_name)).execution_options(
+                        autocommit=True
+                    )
                 )
         elif load_mode == LoadMode.REPLACE:
             # Pandas and SQLAlchemy seem to have problems using if_exists="replace"
@@ -163,24 +207,49 @@ class DataCheckSql:
             )
             return True
 
-    def get_date_columns(self, table_name: str):
+    def get_column_types(self, table_name: str):
         schema, name = self._parse_table_name(table_name)
+        try:
+            inspector = inspect(self.get_connection())
+            columns = inspector.get_columns(name, schema=schema)
+            return {c["name"]: c["type"] for c in columns}
+        except (NoSuchTableError, OperationalError):
+            # Python 3.6 might trow an OperationalError
+            return {}
+
+    def get_date_columns(self, table_name: str):
         date_column_types = (
             datetime.datetime,
             datetime.date,
             datetime.time,
         )
-        try:
-            inspector = inspect(self.get_connection())
-            columns = inspector.get_columns(name, schema=schema)
-            return {
-                c["name"]: c["type"]
-                for c in columns
-                if c["type"].python_type in date_column_types
-            }
-        except (NoSuchTableError, OperationalError):
-            # Python 3.6 might trow an OperationalError
-            return {}
+        col_types = self.get_column_types(table_name)
+        return {
+            k: col_types[k]
+            for k in col_types.keys()
+            if col_types[k].python_type in date_column_types
+        }
+
+    def get_string_columns(self, table_name: str):
+        col_types = self.get_column_types(table_name)
+        return {
+            k: col_types[k] for k in col_types.keys() if col_types[k].python_type == str
+        }
+
+    def get_column_info(self, table_name: str) -> ColumnInfo:
+        date_columns = self.get_date_columns(table_name)
+        date_column_names = list(date_columns.keys())
+        string_columns = self.get_string_columns(table_name)
+        string_column_names = list(string_columns.keys())
+        dtypes = dict(date_columns, **string_columns)
+        column_info = ColumnInfo(
+            dtypes=dtypes,
+            date_columns=date_columns,
+            date_column_names=date_column_names,
+            string_columns=string_columns,
+            string_column_names=string_column_names,
+        )
+        return column_info
 
     def load_table_from_csv_file(
         self,
@@ -192,14 +261,18 @@ class DataCheckSql:
         if isinstance(load_mode, str):
             load_mode = self.load_mode_from_string(load_mode)
         rel_file = base_path / file
-        date_columns = self.get_date_columns(table)
-        date_column_names = list(date_columns.keys())
-        data = read_csv(csv_file=rel_file, parse_dates=date_column_names)
+        column_info = self.get_column_info(table)
+
+        data = read_csv(
+            csv_file=rel_file,
+            parse_dates=column_info.date_column_names,
+            string_columns=column_info.string_column_names,
+        )
         result = self.load_table(
             table_name=table,
             data=data,
             load_mode=load_mode,
-            dtype=date_columns,
+            dtype=column_info.dtypes,
         )
         if result:
             print(f"table {table} loaded from {rel_file}")
@@ -228,9 +301,18 @@ class DataCheckSql:
     def load_mode_from_string(lm_str: str) -> LoadMode:
         return LoadMode.from_string(lm_str)
 
-    def run_sql(self, sql_text: str):
-        sq_text = text(sql_text)
+    def run_sql(
+        self, query: str, output: Union[str, Path] = "", base_path: Path = Path(".")
+    ):
+        sq_text = text(query)
         result = self.get_connection().execute(
             sq_text.execution_options(autocommit=True)
         )
-        return result
+        try:
+            res = result.fetchall()
+            df = pd.DataFrame(data=res, columns=result.keys())
+            print_csv(df)
+            write_csv(df, output=output, base_path=base_path)
+            return res
+        except:
+            return bool(result)
